package com.dayou.mapper;

import com.dayou.entity.AssetsEvaluationTarget;
import com.dayou.dao.CustomBaseMapper;
import com.dayou.vo.AssetsEvaluationTargetVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * <p>
 * 资产评估对象表 Mapper 接口
 * </p>
 *
 * @author GouGengquan
 * @since 2024-03-28
 */
public interface AssetsEvaluationTargetMapper extends CustomBaseMapper<AssetsEvaluationTarget> {

    /**
     * 根据资产业务订单id获取评估对象信息
     * @param id 资产订单id
     * @return List<AssetsEvaluationTargetVO>
     */
    List<AssetsEvaluationTargetVO> getAETargetListByAssetsId(@Param("id") Long id,@Param("productionNo") String productionNo);

    /**
     * 评估对象添加产品号
     * @param id 评估对象id
     * @param productionNo 产品号
     * @return BOolean
     */
    Boolean updateTargetProductionNo(@Param("id") Long id, @Param("productionNo") String productionNo);

    /**
     * 根据业务id获取已取号评估对象的产品号
     * @param businessId 资产业务id
     * @return List<String>
     */
    List<String> getProductionNoList(@Param("businessId") Long businessId);

    /**
     * 评估对象审核定价
     * @param assetsEvaluationTarget 审核定价信息
     * @return Boolean
     */
    Boolean checkValue(AssetsEvaluationTarget assetsEvaluationTarget);
}
